sequencetools.is_integer_equivalent_singleton
=============================================

.. autofunction:: abjad.tools.sequencetools.is_integer_equivalent_singleton.is_integer_equivalent_singleton
